***********************
:mod:`mopidy.frontends`
***********************

A frontend is responsible for exposing Mopidy for a type of clients.


Frontend API
============

.. warning::

    A stable frontend API is not available yet, as we've only implemented a
    couple of frontend modules.

.. automodule:: mopidy.frontends.base
    :synopsis: Base class for frontends
    :members:


Frontends
=========

* :mod:`mopidy.frontends.lastfm`
* :mod:`mopidy.frontends.mpd`
